==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/pool_historical_prepayments.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_service_get_historical_prepayments_response_200_prepayments_item import (
    PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItem,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolHistoricalPrepayments")


@attr.s(auto_attribs=True)
class PoolHistoricalPrepayments:
    """  """

    prepayments: Union[
        Unset, List[PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItem]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        prepayments: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.prepayments, Unset):
            prepayments = []
            for prepayments_item_data in self.prepayments:
                prepayments_item = prepayments_item_data.to_dict()

                prepayments.append(prepayments_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if prepayments is not UNSET:
            field_dict["prepayments"] = prepayments

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        prepayments = []
        _prepayments = d.pop("prepayments", UNSET)
        for prepayments_item_data in _prepayments or []:
            prepayments_item = PoolService_GetHistoricalPrepaymentsResponse_200PrepaymentsItem.from_dict(
                prepayments_item_data
            )

            prepayments.append(prepayments_item)

        pool_historical_prepayments = cls(
            prepayments=prepayments,
        )

        pool_historical_prepayments.additional_properties = d
        return pool_historical_prepayments

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.259.0-py3-none-any.whl: infima_client/models/pool_historical_prepayments.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_prepayment import PoolPrepayment
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolHistoricalPrepayments")


@attr.s(auto_attribs=True)
class PoolHistoricalPrepayments:
    """  """

    prepayments: Union[Unset, List[PoolPrepayment]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        prepayments: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.prepayments, Unset):
            prepayments = []
            for prepayments_item_data in self.prepayments:
                prepayments_item = prepayments_item_data.to_dict()

                prepayments.append(prepayments_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if prepayments is not UNSET:
            field_dict["prepayments"] = prepayments

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        prepayments = []
        _prepayments = d.pop("prepayments", UNSET)
        for prepayments_item_data in _prepayments or []:
            prepayments_item = PoolPrepayment.from_dict(prepayments_item_data)

            prepayments.append(prepayments_item)

        pool_historical_prepayments = cls(
            prepayments=prepayments,
        )

        pool_historical_prepayments.additional_properties = d
        return pool_historical_prepayments

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
